@@ -2,7 +2,12 @@ import json
 
 import requests
 
-from fhir_cli import FHIR_API_PASSWORD, FHIR_API_URL, FHIR_API_USER
+from fhir_cli import (
+    FHIR_API_PASSWORD,
+    FHIR_API_URL,
+    FHIR_API_USER,
+    SELF_SIGNED_CERTIFICATE_PATH,
+)
 from utils.prettify_json import prettify_json
 
 
@@ -43,6 +48,7 @@ class FhirResource:
             raise FhirValidationError("resource has no resource type")
         r = requests.post(
             f"{FHIR_API_URL}/{resource_type}/$validate{f'?profile={profile}' if profile else ''}",
+            verify=SELF_SIGNED_CERTIFICATE_PATH,
             data=serialized_data,
             headers={"Content-Type": "application/json+fhir"},
             auth=(FHIR_API_USER, FHIR_API_PASSWORD)
